@@ -5,9 +5,13 @@ use warnings;
 
 package Net::Fritz::Box;
 # ABSTRACT: main configuration and entry point for L<Net::Fritz> distribution
-$Net::Fritz::Box::VERSION = 'v0.0.2';
+$Net::Fritz::Box::VERSION = 'v0.0.3';
 
-use LWP::UserAgent;
+# We need LWP::UserAgent 6.00 because of ssl_opts.  We could work with
+# an older version as seen in # https://github.com/rhuss/jmx4perl/issues/28
+# but SOAP::Lite might then have the same problem...  For now just
+# stick with the versioned dependency.
+use LWP::UserAgent 6.00;
 use XML::Simple qw(:strict);
 
 use Net::Fritz::Error;
@@ -112,7 +116,7 @@ Net::Fritz::Box - main configuration and entry point for L<Net::Fritz> distribut
 
 =head1 VERSION
 
-version v0.0.2
+version v0.0.3
 
 =head1 SYNOPSIS
 
